# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.11.1-v202502271106-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class LockErrorPathOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'child_relationship': 'str',
        'id': 'str',
        'item': 'BaseOutput'
    }

    attribute_map = {
        'child_relationship': 'childRelationship',
        'id': 'id',
        'item': 'item'
    }

    def __init__(self, child_relationship=None, id=None, item=None):
        """
        LockErrorPathOutputV1 - a model defined in Swagger
        """

        self._child_relationship = None
        self._id = None
        self._item = None

        if child_relationship is not None:
          self.child_relationship = child_relationship
        if id is not None:
          self.id = id
        if item is not None:
          self.item = item

    @property
    def child_relationship(self):
        """
        Gets the child_relationship of this LockErrorPathOutputV1.
        The relationship the item has to its direct child in the path

        :return: The child_relationship of this LockErrorPathOutputV1.
        :rtype: str
        """
        return self._child_relationship

    @child_relationship.setter
    def child_relationship(self, child_relationship):
        """
        Sets the child_relationship of this LockErrorPathOutputV1.
        The relationship the item has to its direct child in the path

        :param child_relationship: The child_relationship of this LockErrorPathOutputV1.
        :type: str
        """
        allowed_values = ["CURRENT_WORKSTEP_IN_A_WORKSHEET", "WORKSHEET", "SCOPED_TO", "HAS_INTEREST", "INTERESTED_IN", "MONITORED_BY", "MONITORS", "REFERENCED_BY_JOURNAL_IN_WORKSHEET", "REFERENCED_BY_WORKSTEP", "POSSIBLE_CHILD", "NO_READ_PERMISSION", "NO_WRITE_PERMISSION", "NO_MANAGE_PERMISSION", "HAS_PARAMETER"]
        if child_relationship not in allowed_values:
            raise ValueError(
                "Invalid value for `child_relationship` ({0}), must be one of {1}"
                .format(child_relationship, allowed_values)
            )

        self._child_relationship = child_relationship

    @property
    def id(self):
        """
        Gets the id of this LockErrorPathOutputV1.
        The id of the item in the path

        :return: The id of this LockErrorPathOutputV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this LockErrorPathOutputV1.
        The id of the item in the path

        :param id: The id of this LockErrorPathOutputV1.
        :type: str
        """

        self._id = id

    @property
    def item(self):
        """
        Gets the item of this LockErrorPathOutputV1.

        :return: The item of this LockErrorPathOutputV1.
        :rtype: BaseOutput
        """
        return self._item

    @item.setter
    def item(self, item):
        """
        Sets the item of this LockErrorPathOutputV1.

        :param item: The item of this LockErrorPathOutputV1.
        :type: BaseOutput
        """

        self._item = item

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, LockErrorPathOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
